EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_PurgeExecutionLogs',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'LogMessagesDeleted_Count',
    /* Description_Text        */ 'Purges execution logs in a specific build before a specified time.'
GO

IF OBJECT_ID('[Builds_PurgeExecutionLogs]') IS NOT NULL DROP PROCEDURE [Builds_PurgeExecutionLogs]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_PurgeExecutionLogs]
(
	@Build_Id INT,
	@Environment_Id INT,
	@PipelineStage_Name VARCHAR(50),
	@Before_Date DATETIME,
	@LogMessagesDeleted_Count BIGINT = NULL OUT
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @ToDelete TABLE ([Execution_Id] INT NOT NULL)

	INSERT INTO @ToDelete
	SELECT PSTE.[Execution_Id]
	  FROM [PipelineStageTargetExecutions] PSTE
		   INNER JOIN [BuildPromotions] BP
		           ON BP.[Promotion_Id] = PSTE.[Promotion_Id]
		   INNER JOIN [Builds] B
			       ON B.[Build_Id] = BP.[Build_Id]
		   INNER JOIN [Executions] E
		           ON E.[Execution_Id] = PSTE.[Execution_Id]
		    LEFT JOIN [Environments] ENV
		           ON ENV.[Environment_Name] = PSTE.[Environment_Name]
	 WHERE B.[Build_Id] = @Build_Id
	   AND (@Environment_Id IS NULL OR ENV.[Environment_Id] = @Environment_Id)
	   AND (@PipelineStage_Name IS NULL OR BP.[PipelineStage_Name] = @PipelineStage_Name)
	   AND (@Before_Date IS NULL OR E.[End_Date] < @Before_Date)

	DELETE
	  FROM [ScopedExecutionLogs]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @ToDelete)

	SET @LogMessagesDeleted_Count = ROWCOUNT_BIG()

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Builds_PurgeExecutionLogs] TO [BuildMasterUser_Role]
